@@ -24,6 +24,9 @@ where
     O: 'static,
     S: 'static + ?Sized,
 {
+    /// This variant is **unstable** and only available with the `unstable` feature.
+    #[cfg(feature = "unstable")] // reason: B: 'static bound may be inconvenient
+    Static(&'static B),
     Borrowed(&'b B),
     Owned(O),
     BorrowedArc(&'b Arc<S>),
@@ -73,6 +76,8 @@ impl<'b, B: ?Sized, O, S: ?Sized> Bos<'b, B, O, S> {
         S: Clone + Into<O>,
     {
         match self {
+            #[cfg(feature = "unstable")]
+            Self::Static(x) => x.to_owned(),
             Self::Borrowed(x) => x.to_owned(),
             Self::Owned(x) => x,
             Self::BorrowedArc(x) => x.deref().clone().into(),
@@ -126,6 +131,11 @@ impl<'b, B: ?Sized, O, S: ?Sized> Bos<'b, B, O, S> {
         S: Clone + BorrowMut<O>,
     {
         match self {
+            #[cfg(feature = "unstable")]
+            Self::Static(x) => {
+                *self = Self::Owned(x.to_owned());
+                self.to_mut()
+            }
             Self::Borrowed(x) => {
                 *self = Self::Owned(x.to_owned());
                 self.to_mut()
@@ -165,6 +175,8 @@ impl<'b, B: ?Sized, O, S: ?Sized> Bos<'b, B, O, S> {
         B: ToOwned<Owned = O>,
     {
         match self {
+            #[cfg(feature = "unstable")]
+            Self::Static(x) => Bos::Static(x),
             Self::Borrowed(x) => Bos::Owned(x.to_owned()),
             Self::Owned(x) => Bos::Owned(x),
             Self::BorrowedArc(x) => Bos::Arc(x.clone()),
@@ -187,6 +199,8 @@ impl<'b, B: ?Sized, O, S: ?Sized> Bos<'b, B, O, S> {
         B: ToOwned<Owned = O>,
     {
         match self {
+            #[cfg(feature = "unstable")]
+            Self::Static(x) => Bos::Static(x),
             Self::Borrowed(x) => Bos::Borrowed(x),
             Self::Owned(x) => Bos::Owned(x),
             Self::BorrowedArc(x) => Bos::Arc(x.deref().borrow().to_owned().into()),
@@ -210,6 +224,8 @@ impl<'b, B: ?Sized, O, S: ?Sized> Bos<'b, B, O, S> {
         for<'a> &'a B: Into<Rc<B>>,
     {
         match self {
+            #[cfg(feature = "unstable")]
+            Self::Static(x) => Bos::Static(x),
             Self::Borrowed(x) => Bos::Borrowed(x),
             Self::Owned(x) => Bos::Owned(x),
             Self::BorrowedArc(x) => Bos::Arc(x.deref().borrow().into()),
@@ -246,6 +262,8 @@ impl<'b, B: ?Sized, O, S: ?Sized> Bos<'b, B, O, S> {
         O: Borrow<B>,
     {
         match self {
+            #[cfg(feature = "unstable")]
+            Self::Static(x) => Bos::Static(x),
             Self::Borrowed(x) => Bos::Borrowed(x),
             Self::Owned(x) => Bos::Borrowed(x.borrow()),
             Self::BorrowedArc(x) => Bos::BorrowedArc(x),
@@ -275,11 +293,7 @@ impl<'b, B: ?Sized, O, S: ?Sized> Bos<'b, B, O, S> {
     {
         match self {
             Self::Owned(x) => Self::Rc(x.into()),
-            Self::Borrowed(_)
-            | Self::BorrowedArc(_)
-            | Self::Arc(_)
-            | Self::BorrowedRc(_)
-            | Self::Rc(_) => self,
+            _ => self,
         }
     }
 
@@ -335,6 +349,8 @@ impl<'b, B: ?Sized, O, S: ?Sized> Bos<'b, B, O, S> {
         S: Borrow<B>,
     {
         match self {
+            #[cfg(feature = "unstable")]
+            Self::Static(x) => x,
             Self::Borrowed(x) => x,
             Self::Owned(x) => x.borrow(),
             Self::BorrowedArc(x) => x.deref().deref().borrow(),
@@ -437,6 +453,8 @@ where
     #[inline]
     fn clone(&self) -> Self {
         match self {
+            #[cfg(feature = "unstable")]
+            Self::Static(x) => Self::Static(x),
             Self::Borrowed(x) => Self::Borrowed(x),
             Self::Owned(x) => Self::Owned(x.clone()),
             Self::BorrowedArc(x) => Self::BorrowedArc(x),
@@ -466,6 +484,8 @@ where
 {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match self {
+            #[cfg(feature = "unstable")]
+            Bos::Static(x) => f.debug_tuple("Bos::Static").field(x).finish(),
             Bos::Borrowed(x) => f.debug_tuple("Bos::Borrowed").field(x).finish(),
             Bos::Owned(x) => f.debug_tuple("Bos::Owned").field(x).finish(),
             Bos::BorrowedArc(x) => f.debug_tuple("Bos::BorrowedArc").field(x).finish(),
@@ -484,6 +504,8 @@ where
 {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match self {
+            #[cfg(feature = "unstable")]
+            Self::Static(x) => fmt::Display::fmt(x, f),
             Self::Borrowed(x) => fmt::Display::fmt(x, f),
             Self::Owned(x) => fmt::Display::fmt(x, f),
             Self::BorrowedArc(x) => fmt::Display::fmt(x, f),
@@ -612,7 +634,7 @@ impl<'b, B: ToOwned + ?Sized + 'b> From<Cow<'b, B>> for Bos<'b, B, B::Owned, B::
 impl<B: ?Sized, O, S: ?Sized> From<&'static B> for Bos<'static, B, O, S> {
     #[inline]
     fn from(x: &'static B) -> Self {
-        Self::Borrowed(x)
+        Self::Static(x)
     }
 }
 
